#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 assoc
version:              1.0.2
visibility:           public
id:                   assoc-1.0.2-2NAY27Pxanp5SGhojPPgAH
key:                  assoc-1.0.2-2NAY27Pxanp5SGhojPPgAH
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             swap and assoc: Symmetric and Semigroupy Bifunctors
description:
    Provides generalisations of
    @swap :: (a,b) -> (b,a)@ and
    @assoc :: ((a,b),c) -> (a,(b,c))@
    to
    @Bifunctor@s supporting similar operations (e.g. @Either@, @These@).

category:             Data
abi:                  93cde373957fe9d6f303459ed1602016
exposed:              True
exposed-modules:      Data.Bifunctor.Assoc Data.Bifunctor.Swap
import-dirs:          /usr/lib/ghc-8.10.5/site-local/assoc-1.0.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/assoc-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/assoc-1.0.2
hs-libraries:         HSassoc-1.0.2-2NAY27Pxanp5SGhojPPgAH
depends:
    base-4.14.2.0 bifunctors-5.5.11-I8MVLGtsycGakOlqrC4OY
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV

haddock-interfaces:   /usr/share/doc/haskell-assoc/html/assoc.haddock
haddock-html:         /usr/share/doc/haskell-assoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

